==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/GetVirtualMachineRunCommandByVirtualMachineResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Describes a Virtual Machine run command.
 * @property asyncExecution Optional. If set to true, provisioning will complete as soon as the script starts and will not wait for script to complete.
 * @property errorBlobManagedIdentity User-assigned managed identity that has access to errorBlobUri storage blob. Use an empty object in case of system-assigned identity. Make sure managed identity has been given access to blob's container with 'Storage Blob Data Contributor' role assignment. In case of user-assigned identity, make sure you add it under VM's identity. For more info on managed identity and Run Command, refer https://aka.ms/ManagedIdentity and https://aka.ms/RunCommandManaged
 * @property errorBlobUri Specifies the Azure storage blob where script error stream will be uploaded. Use a SAS URI with read, append, create, write access OR use managed identity to provide the VM access to the blob. Refer errorBlobManagedIdentity parameter.
 * @property id Resource Id
 * @property instanceView The virtual machine run command instance view.
 * @property location Resource location
 * @property name Resource name
 * @property outputBlobManagedIdentity User-assigned managed identity that has access to outputBlobUri storage blob. Use an empty object in case of system-assigned identity. Make sure managed identity has been given access to blob's container with 'Storage Blob Data Contributor' role assignment. In case of user-assigned identity, make sure you add it under VM's identity. For more info on managed identity and Run Command, refer https://aka.ms/ManagedIdentity and https://aka.ms/RunCommandManaged
 * @property outputBlobUri Specifies the Azure storage blob where script output stream will be uploaded. Use a SAS URI with read, append, create, write access OR use managed identity to provide the VM access to the blob. Refer outputBlobManagedIdentity parameter.
 * @property parameters The parameters used by the script.
 * @property protectedParameters The parameters used by the script.
 * @property provisioningState The provisioning state, which only appears in the response. If treatFailureAsDeploymentFailure set to true, any failure in the script will fail the deployment and ProvisioningState will be marked as Failed. If treatFailureAsDeploymentFailure set to false, ProvisioningState would only reflect whether the run command was run or not by the extensions platform, it would not indicate whether script failed in case of script failures. See instance view of run command in case of script failures to see executionMessage, output, error: https://aka.ms/runcommandmanaged#get-execution-status-and-results
 * @property runAsPassword Specifies the user account password on the VM when executing the run command.
 * @property runAsUser Specifies the user account on the VM when executing the run command.
 * @property source The source of the run command script.
 * @property tags Resource tags
 * @property timeoutInSeconds The timeout in seconds to execute the run command.
 * @property treatFailureAsDeploymentFailure Optional. If set to true, any failure in the script will fail the deployment and ProvisioningState will be marked as Failed. If set to false, ProvisioningState would only reflect whether the run command was run or not by the extensions platform, it would not indicate whether script failed in case of script failures. See instance view of run command in case of script failures to see executionMessage, output, error: https://aka.ms/runcommandmanaged#get-execution-status-and-results
 * @property type Resource type
 */
public data class GetVirtualMachineRunCommandByVirtualMachineResult(
    public val asyncExecution: Boolean? = null,
    public val errorBlobManagedIdentity: RunCommandManagedIdentityResponse? = null,
    public val errorBlobUri: String? = null,
    public val id: String,
    public val instanceView: VirtualMachineRunCommandInstanceViewResponse,
    public val location: String,
    public val name: String,
    public val outputBlobManagedIdentity: RunCommandManagedIdentityResponse? = null,
    public val outputBlobUri: String? = null,
    public val parameters: List<RunCommandInputParameterResponse>? = null,
    public val protectedParameters: List<RunCommandInputParameterResponse>? = null,
    public val provisioningState: String,
    public val runAsPassword: String? = null,
    public val runAsUser: String? = null,
    public val source: VirtualMachineRunCommandScriptSourceResponse? = null,
    public val tags: Map<String, String>? = null,
    public val timeoutInSeconds: Int? = null,
    public val treatFailureAsDeploymentFailure: Boolean? = null,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.GetVirtualMachineRunCommandByVirtualMachineResult):
            GetVirtualMachineRunCommandByVirtualMachineResult =
            GetVirtualMachineRunCommandByVirtualMachineResult(
                asyncExecution = javaType.asyncExecution().map({ args0 -> args0 }).orElse(null),
                errorBlobManagedIdentity = javaType.errorBlobManagedIdentity().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandManagedIdentityResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                errorBlobUri = javaType.errorBlobUri().map({ args0 -> args0 }).orElse(null),
                id = javaType.id(),
                instanceView = javaType.instanceView().let({ args0 ->
                    com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineRunCommandInstanceViewResponse.Companion.toKotlin(args0)
                }),
                location = javaType.location(),
                name = javaType.name(),
                outputBlobManagedIdentity = javaType.outputBlobManagedIdentity().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandManagedIdentityResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                outputBlobUri = javaType.outputBlobUri().map({ args0 -> args0 }).orElse(null),
                parameters = javaType.parameters().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandInputParameterResponse.Companion.toKotlin(args0)
                    })
                }),
                protectedParameters = javaType.protectedParameters().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandInputParameterResponse.Companion.toKotlin(args0)
                    })
                }),
                provisioningState = javaType.provisioningState(),
                runAsPassword = javaType.runAsPassword().map({ args0 -> args0 }).orElse(null),
                runAsUser = javaType.runAsUser().map({ args0 -> args0 }).orElse(null),
                source = javaType.source().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineRunCommandScriptSourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                timeoutInSeconds = javaType.timeoutInSeconds().map({ args0 -> args0 }).orElse(null),
                treatFailureAsDeploymentFailure = javaType.treatFailureAsDeploymentFailure().map({ args0 ->
                    args0
                }).orElse(null),
                type = javaType.type(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/GetVirtualMachineRunCommandByVirtualMachineResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.Map

/**
 * Describes a Virtual Machine run command.
 * @property asyncExecution Optional. If set to true, provisioning will complete as soon as the script starts and will not wait for script to complete.
 * @property errorBlobManagedIdentity User-assigned managed identity that has access to errorBlobUri storage blob. Use an empty object in case of system-assigned identity. Make sure managed identity has been given access to blob's container with 'Storage Blob Data Contributor' role assignment. In case of user-assigned identity, make sure you add it under VM's identity. For more info on managed identity and Run Command, refer https://aka.ms/ManagedIdentity and https://aka.ms/RunCommandManaged
 * @property errorBlobUri Specifies the Azure storage blob where script error stream will be uploaded. Use a SAS URI with read, append, create, write access OR use managed identity to provide the VM access to the blob. Refer errorBlobManagedIdentity parameter.
 * @property id Resource Id
 * @property instanceView The virtual machine run command instance view.
 * @property location Resource location
 * @property name Resource name
 * @property outputBlobManagedIdentity User-assigned managed identity that has access to outputBlobUri storage blob. Use an empty object in case of system-assigned identity. Make sure managed identity has been given access to blob's container with 'Storage Blob Data Contributor' role assignment. In case of user-assigned identity, make sure you add it under VM's identity. For more info on managed identity and Run Command, refer https://aka.ms/ManagedIdentity and https://aka.ms/RunCommandManaged
 * @property outputBlobUri Specifies the Azure storage blob where script output stream will be uploaded. Use a SAS URI with read, append, create, write access OR use managed identity to provide the VM access to the blob. Refer outputBlobManagedIdentity parameter.
 * @property parameters The parameters used by the script.
 * @property protectedParameters The parameters used by the script.
 * @property provisioningState The provisioning state, which only appears in the response. If treatFailureAsDeploymentFailure set to true, any failure in the script will fail the deployment and ProvisioningState will be marked as Failed. If treatFailureAsDeploymentFailure set to false, ProvisioningState would only reflect whether the run command was run or not by the extensions platform, it would not indicate whether script failed in case of script failures. See instance view of run command in case of script failures to see executionMessage, output, error: https://aka.ms/runcommandmanaged#get-execution-status-and-results
 * @property runAsPassword Specifies the user account password on the VM when executing the run command.
 * @property runAsUser Specifies the user account on the VM when executing the run command.
 * @property source The source of the run command script.
 * @property tags Resource tags
 * @property timeoutInSeconds The timeout in seconds to execute the run command.
 * @property treatFailureAsDeploymentFailure Optional. If set to true, any failure in the script will fail the deployment and ProvisioningState will be marked as Failed. If set to false, ProvisioningState would only reflect whether the run command was run or not by the extensions platform, it would not indicate whether script failed in case of script failures. See instance view of run command in case of script failures to see executionMessage, output, error: https://aka.ms/runcommandmanaged#get-execution-status-and-results
 * @property type Resource type
 */
public data class GetVirtualMachineRunCommandByVirtualMachineResult(
    public val asyncExecution: Boolean? = null,
    public val errorBlobManagedIdentity: RunCommandManagedIdentityResponse? = null,
    public val errorBlobUri: String? = null,
    public val id: String,
    public val instanceView: VirtualMachineRunCommandInstanceViewResponse,
    public val location: String,
    public val name: String,
    public val outputBlobManagedIdentity: RunCommandManagedIdentityResponse? = null,
    public val outputBlobUri: String? = null,
    public val parameters: List<RunCommandInputParameterResponse>? = null,
    public val protectedParameters: List<RunCommandInputParameterResponse>? = null,
    public val provisioningState: String,
    public val runAsPassword: String? = null,
    public val runAsUser: String? = null,
    public val source: VirtualMachineRunCommandScriptSourceResponse? = null,
    public val tags: Map<String, String>? = null,
    public val timeoutInSeconds: Int? = null,
    public val treatFailureAsDeploymentFailure: Boolean? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.GetVirtualMachineRunCommandByVirtualMachineResult): GetVirtualMachineRunCommandByVirtualMachineResult =
            GetVirtualMachineRunCommandByVirtualMachineResult(
                asyncExecution = javaType.asyncExecution().map({ args0 -> args0 }).orElse(null),
                errorBlobManagedIdentity = javaType.errorBlobManagedIdentity().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandManagedIdentityResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                errorBlobUri = javaType.errorBlobUri().map({ args0 -> args0 }).orElse(null),
                id = javaType.id(),
                instanceView = javaType.instanceView().let({ args0 ->
                    com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineRunCommandInstanceViewResponse.Companion.toKotlin(args0)
                }),
                location = javaType.location(),
                name = javaType.name(),
                outputBlobManagedIdentity = javaType.outputBlobManagedIdentity().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandManagedIdentityResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                outputBlobUri = javaType.outputBlobUri().map({ args0 -> args0 }).orElse(null),
                parameters = javaType.parameters().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandInputParameterResponse.Companion.toKotlin(args0)
                    })
                }),
                protectedParameters = javaType.protectedParameters().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.RunCommandInputParameterResponse.Companion.toKotlin(args0)
                    })
                }),
                provisioningState = javaType.provisioningState(),
                runAsPassword = javaType.runAsPassword().map({ args0 -> args0 }).orElse(null),
                runAsUser = javaType.runAsUser().map({ args0 -> args0 }).orElse(null),
                source = javaType.source().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineRunCommandScriptSourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
                timeoutInSeconds = javaType.timeoutInSeconds().map({ args0 -> args0 }).orElse(null),
                treatFailureAsDeploymentFailure = javaType.treatFailureAsDeploymentFailure().map({ args0 ->
                    args0
                }).orElse(null),
                type = javaType.type(),
            )
    }
}
